import { CommonModule } from "@angular/common";
import { Component, OnInit } from "@angular/core";
import { JobService } from "../../data-access/services/JobService.service";
import { NzTableModule, NzTableQueryParams } from 'ng-zorro-antd/table';
import { catchError, finalize, of, tap } from "rxjs";
import { JobModel } from "../../data-access/model/jobModel.model";
import { NzDividerModule } from 'ng-zorro-antd/divider';
import { NzButtonModule } from "ng-zorro-antd/button";
import { NzSpaceModule } from 'ng-zorro-antd/space';


@Component({
  selector: "app-job-list",
  templateUrl: "./jobList.component.html",
  standalone: true,
  imports: [CommonModule,
    NzTableModule,
    NzDividerModule,
    NzButtonModule,
    NzSpaceModule
  ],
})
export class JobListComponent implements OnInit {

  total = 1;
  listOfJob: JobModel[] = [];
  loading = true;
  pageSize = 15;
  pageIndex = 1;

  loadDataFromServer(
    pageIndex: number,
    pageSize: number
  ): void {
    this.loading = true;
    this.jobService.jobsGet(pageIndex, pageSize).pipe(
      tap((res) => {
        this.loading = false;
        this.total = res.total;
        this.listOfJob = res.responseData.items;
        console.log(this.listOfJob);
      }),
      catchError((err) => {
        console.log(err);
        return of(null);
      })
    ).subscribe();
  }

  constructor(private jobService: JobService) {}

  ngOnInit(): void {
    this.loadDataFromServer(this.pageIndex, this.pageSize);
  }
  onEdit(data: any) {
    console.log(data);
  }


}
